Python: module mlock

mlock | index /tmp/makerelease-pwman-python.NVQhFLFA/pwman-python-2.8/libpwman/mlock.py

# mlock support
# Copyright (c) 2019-2023 Michael Büsch <m@bues.ch>
# Licensed under the GNU/GPL version 2 or later.

Modules
os | platform | sys |

Classes
|  | builtins.object MLockWrapper
class MLockWrapper(builtins.object)
| OS mlock wrapper.
| Methods defined here: __init__(self) Initialize self. See help(type(self)) for accurate signature. Class methods defined here: get() from builtins.type mlockall(flags) from builtins.type munlockall() from builtins.type Data descriptors defined here: __dict__ dictionary for instance variables (if defined) __weakref__ list of weak references to the object (if defined) Data and other attributes defined here: MCL_CURRENT = 1 MCL_FUTURE = 2 MCL_ONFAULT = 4 singleton = None

Data
|  | __all__ = ['MLockWrapper']